==> qtjambi-scxml-debuginfo-macos-5.15.20.jar: sources/QtJambiScxml/QScxmlStateMachine_shell.h <==
#ifndef QSCXMLSTATEMACHINE_SHELL_H
#define QSCXMLSTATEMACHINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtScxml/qscxmlstatemachine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/JObjectWrapper>
#include <QtJambi/JavaAPI>
#include <QtScxml/qscxmlcompiler.h>
#include <QtScxml/qscxmldatamodel.h>
#include <QtScxml/qscxmlerror.h>
#include <QtScxml/qscxmlevent.h>
#include <QtScxml/qscxmlinvokableservice.h>
#include <QtScxml/qscxmltabledata.h>
#include <QtJambi/RegistryAPI>


class QScxmlStateMachine_shell : public QScxmlStateMachine, public QtJambiShellInterface
{
public:
    QScxmlStateMachine_shell(const QMetaObject* metaObject0, QObject* parent1 = nullptr);
    ~QScxmlStateMachine_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScxmlStateMachine_access : public QScxmlStateMachine
{
    jboolean __qt_isActive_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint stateIndex0) const;
};

#endif // QSCXMLSTATEMACHINE_SHELL_H

==> qtjambi-scxml-debuginfo-macos-6.6.3.jar: sources/QtJambiScxml/QScxmlStateMachine_shell.h <==
#ifndef QSCXMLSTATEMACHINE_SHELL_H
#define QSCXMLSTATEMACHINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtScxml/qscxmlstatemachine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/JObjectWrapper>
#include <QtJambi/JavaAPI>
#include <QtScxml/qscxmlcompiler.h>
#include <QtScxml/qscxmldatamodel.h>
#include <QtScxml/qscxmlerror.h>
#include <QtScxml/qscxmlevent.h>
#include <QtScxml/qscxmlinvokableservice.h>
#include <QtScxml/qscxmltabledata.h>
#include <QtJambi/RegistryAPI>


class QScxmlStateMachine_shell : public QScxmlStateMachine, public QtJambiShellInterface
{
public:
    QScxmlStateMachine_shell(const QMetaObject* metaObject0, QObject* parent1 = nullptr);
    ~QScxmlStateMachine_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScxmlStateMachine_access : public QScxmlStateMachine
{
    jboolean __qt_isActive_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint stateIndex0) const;
};

#endif // QSCXMLSTATEMACHINE_SHELL_H
